require "olya/version"
require 'uri'
require 'yaml'
require 'rest-client'
require 'json'

module Olya
  class BibblioAuth

  attr_accessor :bibblio_auth, :session, :base_url

  def initialize(config_yml, url = "https://api.bibblio.org/token")
    @bibblio_auth ||= parse_yaml(config_yml)
    @base_url     ||= url
  end

  def parse_yaml(yaml_file)
    YAML.load_file(File.join(Dir.pwd, yaml_file))
  end

  def session
    @session ||= auth_to_olya(base_url)
  end

  def headers
    @bibblio_auth[:headers] ||= Hash.new(:content_type => 'application/x-www-form-urlencoded')
  end

  def auth_to_olya(base_url)
    values = "client_id=#{bibblio_auth["credentials"]["client_id"]}&client_secret=#{bibblio_auth["credentials"]["client_secret"]}"

    begin
      response = RestClient.post base_url, values, headers
    rescue => e
      # handle 401 402 403
      response = {}
    end
    response = JSON.parse(response)
  end

  end
end
